import { Meta, StoryObj } from '@storybook/react';
import { Tooltip, TooltipTrigger, TooltipContent, TooltipProvider } from '@/lib';

export default {
  title: 'Components/Tooltip',
  component: Tooltip,
  decorators: [
    Story => (
      <div className="p-10">
        <Story />
      </div>
    ),
  ],

  argTypes: {
    placement: {
      control: 'inline-radio',
      options: ['top', 'bottom', 'left', 'right'],
      description: 'Tooltip placement relative to the trigger',
    },
    groupDelay: {
      control: 'boolean',
      description: 'Wrap the tooltip in a TooltipProvider to apply group delay',
    },
    delayOpen: {
      control: 'number',
      description: 'Delay before the tooltip opens (ms)',
    },
    delayClose: {
      control: 'number',
      description: 'Delay before the tooltip closes (ms)',
    },
    showArrow: {
      control: 'boolean',
      description: 'Show an arrow on the tooltip',
    },

    children: { table: { disable: true } },
    boundaryElement: { table: { disable: true } },
    interactive: { table: { disable: true } },
    delay: { table: { disable: true } },
    onOpenChange: { table: { disable: true } },
    open: { table: { disable: true } },
    initialOpen: { table: { disable: true } },
  },
} as Meta;

const Template = (args: any) => {
  return (
    <div className="p-10 flex flex-col gap-1 items-center justify-center">
      {/* ✅ Conditionally wrap in TooltipProvider */}
      {args.groupDelay ? (
        <TooltipProvider delay={{ open: args.delayOpen, close: args.delayClose }}>
          <TooltipInstance {...args} />
          <TooltipInstance {...args} />
          <TooltipInstance {...args} />
        </TooltipProvider>
      ) : (
        <TooltipInstance {...args} />
      )}
    </div>
  );
};

const TooltipInstance = ({ placement, showArrow, delayOpen, delayClose, groupDelay }: any) => (
  <Tooltip
    placement={placement}
    showArrow={showArrow}
    {...(!groupDelay && { delay: { open: delayOpen, close: delayClose } })} // ✅ Remove delay if groupDelay is true
  >
    <TooltipTrigger>
      <button className="border px-3 py-2 hover:text-primary rounded">Hover me</button>
    </TooltipTrigger>
    <TooltipContent>Tooltip at {placement}</TooltipContent>
  </Tooltip>
);

export const Default: StoryObj = {
  render: Template,
  args: {
    placement: 'top',
    showArrow: false,
    delayOpen: 500,
    delayClose: 150,
    groupDelay: false,
  },
};
